==> python-hacking-0.13.0-1-any.pkg.tar.xz: usr/lib/python3.6/site-packages/hacking/tests/test_local.py <==
# Copyright (c) 2013 Hewlett-Packard Development Company, L.P.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from flake8.api import legacy as engine
import mock
import pycodestyle

from hacking import core
import hacking.tests


def check(physical_line):
    """Test check to make sure local-checks are working."""
    if physical_line.strip() == "#this-is-the-test-phrase":
        return (0, "L100: Found local-check test case")


class HackingTestCase(hacking.tests.TestCase):
    def test_local_check(self):
        flake8_style = engine.get_style_guide(parse_argv=False, ignore='F')
        report = pycodestyle.BaseReport(flake8_style.options)
        line = ["#this-is-the-test-phrase"]
        checker = pycodestyle.Checker(lines=line, options=flake8_style.options,
                               report=report)
        checker.check_all()
        self.assertIn("L100", report.counters)

    @mock.patch.object(core, 'CONF')
    def test_local_check_factory_cli_option(self, mock_conf):
        mock_opts = mock.Mock()
        mock_opts.factory = 'mypkg.factory'
        self.assertRaises(
            ImportError, core.ProxyChecks.parse_options, mock_opts)
        self.assertFalse(mock_conf.called)

==> python-hacking-1.0.0-1-any.pkg.tar.xz: usr/lib/python3.6/site-packages/hacking/tests/test_local.py <==
# Copyright (c) 2013 Hewlett-Packard Development Company, L.P.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from flake8.api import legacy as engine
import pycodestyle

import hacking.tests


def check(physical_line):
    """Test check to make sure local-checks are working."""
    if physical_line.strip() == "#this-is-the-test-phrase":
        return (0, "L100: Found local-check test case")


class HackingTestCase(hacking.tests.TestCase):
    def test_local_check(self):
        flake8_style = engine.get_style_guide(parse_argv=False, ignore='F')
        self.options.benchmark_keys = pycodestyle.BENCHMARK_KEYS
        self.options.ignore_code = pycodestyle.StyleGuide.ignore_code
        self.options.physical_checks = []
        self.options.logical_checks = []
        self.options.ast_checks = []
        report = pycodestyle.BaseReport(flake8_style.options)
        line = ["#this-is-the-test-phrase"]
        checker = pycodestyle.Checker(lines=line, options=flake8_style.options,
                               report=report)
        checker.check_all()
        self.assertIn("L100", report.counters)
